Learn R Programming

babelgene (version 22.9)

orthologs: Retrieve gene orthologs/homologs

Description

Retrieve gene orthologs/homologs for a set of genes. Converts between human and non-human analogs.

Usage

orthologs(genes, species, human = TRUE, min_support = 3, top = TRUE)

Value

A data frame of gene pairs (human and given species).

Arguments

genes

A vector of gene symbols or Entrez/Ensembl IDs.

species

Species name, such as Mus musculus or mouse (see species() for options).

human

A logical scalar indicating if the input genes are human. If TRUE, the input genes are human. If FALSE, the input genes correspond to the non-human species and the output will be the human equivalents.

min_support

Minimum number of supporting source databases. Gene pairs available in this package are supported by 2 to 12 databases (the maximum varies depending on the species).

top

For each gene, output only the match with the highest support level if there are multiple hits.

References

Wright MW, Eyre TA, Lush MJ, Povey S, Bruford EA. HCOP: the HGNC comparison of orthology predictions search tool. Mamm Genome. 2005 Nov;16(11):827-8. tools:::Rd_expr_doi("10.1007/s00335-005-0103-2")

Eyre TA, Wright MW, Lush MJ, Bruford EA. HCOP: a searchable database of human orthology predictions. Brief Bioinform. 2007 Jan;8(1):2-5. tools:::Rd_expr_doi("10.1093/bib/bbl030")

Seal RL, Gordon SM, Lush MJ, Wright MW, Bruford EA. genenames.org: the HGNC resources in 2011. Nucleic Acids Res. 2011 Jan;39:D514-9. tools:::Rd_expr_doi("10.1093/nar/gkq892")

Examples

Run this code
orthologs(genes = "TP53", species = "mouse", human = TRUE)
orthologs(genes = c("Ptprc", "Cd34"), species = "mouse", human = FALSE)

Run the code above in your browser using DataLab